@@ -39,4 +39,35 @@ from .config import default_float, default_int, default_jitter
 from .utilities import set_trainable
 from .versions import __version__
 
-__all__ = [export for export in dir()]
+__all__ = [
+    "Module",
+    "Parameter",
+    "__version__",
+    "base",
+    "ci_utils",
+    "conditionals",
+    "config",
+    "covariances",
+    "default_float",
+    "default_int",
+    "default_jitter",
+    "expectations",
+    "experimental",
+    "inducing_variables",
+    "kernels",
+    "kullback_leiblers",
+    "likelihoods",
+    "logdensities",
+    "mean_functions",
+    "models",
+    "monitor",
+    "mypy_flags",
+    "optimizers",
+    "posteriors",
+    "probability_distributions",
+    "quadrature",
+    "set_trainable",
+    "type_flags",
+    "utilities",
+    "versions",
+]
