@@ -14,6 +14,7 @@
 
 import itertools
 from functools import reduce
+from typing import Type, Union
 
 import tensorflow as tf
 
@@ -24,11 +25,13 @@ from ..probability_distributions import DiagonalGaussian, Gaussian, MarkovGaussi
 from . import dispatch
 from .expectations import expectation
 
-NoneType = type(None)
+NoneType: Type[None] = type(None)
 
 
 @dispatch.expectation.register(Gaussian, kernels.Sum, NoneType, NoneType, NoneType)
-def _E(p, kernel, _, __, ___, nghp=None):
+def _expectation_gaussian_sum(
+    p: Gaussian, kernel: kernels.Sum, _: None, __: None, ___: None, nghp: None = None
+) -> tf.Tensor:
     r"""
     Compute the expectation:
     <\Sum_i diag(Ki_{X, X})>_p(X)
@@ -41,7 +44,14 @@ def _E(p, kernel, _, __, ___, nghp=None):
 
 
 @dispatch.expectation.register(Gaussian, kernels.Sum, InducingPoints, NoneType, NoneType)
-def _E(p, kernel, inducing_variable, _, __, nghp=None):
+def _expectation_gaussian_sum_inducingpoints(
+    p: Gaussian,
+    kernel: kernels.Sum,
+    inducing_variable: InducingPoints,
+    _: None,
+    __: None,
+    nghp: None = None,
+) -> tf.Tensor:
     r"""
     Compute the expectation:
     <\Sum_i Ki_{X, Z}>_p(X)
@@ -56,7 +66,14 @@ def _E(p, kernel, inducing_variable, _, __, nghp=None):
 @dispatch.expectation.register(
     Gaussian, (mfn.Linear, mfn.Identity, mfn.Constant), NoneType, kernels.Sum, InducingPoints
 )
-def _E(p, mean, _, kernel, inducing_variable, nghp=None):
+def _expectation_gaussian_linear__sum_inducingpoints(
+    p: Gaussian,
+    mean: Union[mfn.Linear, mfn.Identity, mfn.Constant],
+    _: None,
+    kernel: kernels.Sum,
+    inducing_variable: InducingPoints,
+    nghp: None = None,
+) -> tf.Tensor:
     r"""
     Compute the expectation:
     expectation[n] = <m(x_n)^T (\Sum_i Ki_{x_n, Z})>_p(x_n)
@@ -69,7 +86,14 @@ def _E(p, mean, _, kernel, inducing_variable, nghp=None):
 
 
 @dispatch.expectation.register(MarkovGaussian, mfn.Identity, NoneType, kernels.Sum, InducingPoints)
-def _E(p, mean, _, kernel, inducing_variable, nghp=None):
+def _expectation_markov__sum_inducingpoints(
+    p: MarkovGaussian,
+    mean: mfn.Identity,
+    _: None,
+    kernel: kernels.Sum,
+    inducing_variable: InducingPoints,
+    nghp: None = None,
+) -> tf.Tensor:
     r"""
     Compute the expectation:
     expectation[n] = <x_{n+1} (\Sum_i Ki_{x_n, Z})>_p(x_{n:n+1})
@@ -84,7 +108,14 @@ def _E(p, mean, _, kernel, inducing_variable, nghp=None):
 @dispatch.expectation.register(
     (Gaussian, DiagonalGaussian), kernels.Sum, InducingPoints, kernels.Sum, InducingPoints
 )
-def _E(p, kern1, feat1, kern2, feat2, nghp=None):
+def _expectation_gaussian_sum_inducingpoints__sum_inducingpoints(
+    p: Union[Gaussian, DiagonalGaussian],
+    kern1: kernels.Sum,
+    feat1: InducingPoints,
+    kern2: kernels.Sum,
+    feat2: InducingPoints,
+    nghp: None = None,
+) -> tf.Tensor:
     r"""
     Compute the expectation:
     expectation[n] = <(\Sum_i K1_i_{Z1, x_n}) (\Sum_j K2_j_{x_n, Z2})>_p(x_n)
