@@ -64,7 +64,8 @@ class GPR_deprecated(GPModel, InternalDataTrainingLossMixin):
         super().__init__(kernel, likelihood, mean_function, num_latent_gps=Y_data.shape[-1])
         self.data = data_input_to_tensor(data)
 
-    def maximum_log_likelihood_objective(self) -> tf.Tensor:
+    # type-ignore is because of changed method signature:
+    def maximum_log_likelihood_objective(self) -> tf.Tensor:  # type: ignore
         return self.log_marginal_likelihood()
 
     def _add_noise_cov(self, K: tf.Tensor) -> tf.Tensor:
@@ -101,7 +102,8 @@ class GPR_deprecated(GPModel, InternalDataTrainingLossMixin):
         .. math::
             p(F* | Y)
 
-        where F* are points on the GP at new data points, Y are noisy observations at training data points.
+        where F* are points on the GP at new data points, Y are noisy observations at training data
+        points.
         """
         X, Y = self.data
         err = Y - self.mean_function(X)
@@ -125,7 +127,10 @@ class GPR_with_posterior(GPR_deprecated):
     enables caching for faster subsequent predictions.
     """
 
-    def posterior(self, precompute_cache=posteriors.PrecomputeCacheType.TENSOR):
+    def posterior(
+        self,
+        precompute_cache: posteriors.PrecomputeCacheType = posteriors.PrecomputeCacheType.TENSOR,
+    ) -> posteriors.GPRPosterior:
         """
         Create the Posterior object which contains precomputed matrices for
         faster prediction.
@@ -153,7 +158,9 @@ class GPR_with_posterior(GPR_deprecated):
             precompute_cache=precompute_cache,
         )
 
-    def predict_f(self, Xnew: InputData, full_cov=False, full_output_cov=False) -> MeanAndVariance:
+    def predict_f(
+        self, Xnew: InputData, full_cov: bool = False, full_output_cov: bool = False
+    ) -> MeanAndVariance:
         """
         For backwards compatibility, GPR's predict_f uses the fused (no-cache)
         computation, which is more efficient during training.
