@@ -13,23 +13,22 @@
 # limitations under the License.
 
 from collections import namedtuple
-from typing import NamedTuple, Optional, Tuple
+from typing import Optional, Tuple
 
 import numpy as np
 import tensorflow as tf
 
-from gpflow.kernels import Kernel
-
 from .. import likelihoods, posteriors
 from ..base import InputData, MeanAndVariance, RegressionData
 from ..config import default_float, default_jitter
 from ..covariances.dispatch import Kuf, Kuu
 from ..inducing_variables import InducingPoints
+from ..kernels import Kernel
 from ..mean_functions import MeanFunction
 from ..utilities import add_noise_cov, to_default_float
 from .model import GPModel
 from .training_mixins import InternalDataTrainingLossMixin
-from .util import data_input_to_tensor, inducingpoint_wrapper
+from .util import InducingPointsLike, data_input_to_tensor, inducingpoint_wrapper
 
 
 class SGPRBase_deprecated(GPModel, InternalDataTrainingLossMixin):
@@ -42,21 +41,22 @@ class SGPRBase_deprecated(GPModel, InternalDataTrainingLossMixin):
         self,
         data: RegressionData,
         kernel: Kernel,
-        inducing_variable: InducingPoints,
+        inducing_variable: InducingPointsLike,
         *,
         mean_function: Optional[MeanFunction] = None,
         num_latent_gps: Optional[int] = None,
         noise_variance: float = 1.0,
     ):
         """
-        `data`:  a tuple of (X, Y), where the inputs X has shape [N, D]
-            and the outputs Y has shape [N, R].
-        `inducing_variable`:  an InducingPoints instance or a matrix of
-            the pseudo inputs Z, of shape [M, D].
-        `kernel`, `mean_function` are appropriate GPflow objects
-
         This method only works with a Gaussian likelihood, its variance is
         initialized to `noise_variance`.
+
+        :param data: a tuple of (X, Y), where the inputs X has shape [N, D]
+            and the outputs Y has shape [N, R].
+        :param inducing_variable:  an InducingPoints instance or a matrix of
+            the pseudo inputs Z, of shape [M, D].
+        :param kernel: An appropriate GPflow kernel object.
+        :param mean_function: An appropriate GPflow mean function object.
         """
         likelihood = likelihoods.Gaussian(noise_variance)
         X_data, Y_data = data_input_to_tensor(data)
@@ -66,7 +66,7 @@ class SGPRBase_deprecated(GPModel, InternalDataTrainingLossMixin):
         self.data = X_data, Y_data
         self.num_data = X_data.shape[0]
 
-        self.inducing_variable = inducingpoint_wrapper(inducing_variable)
+        self.inducing_variable: InducingPoints = inducingpoint_wrapper(inducing_variable)
 
     def upper_bound(self) -> tf.Tensor:
         """
@@ -78,18 +78,7 @@ class SGPRBase_deprecated(GPModel, InternalDataTrainingLossMixin):
         known to produce poor inducing point locations. An optimisable upper bound
         can be found in https://github.com/markvdw/gp_upper.
 
-        The key reference is
-
-        ::
-
-          @misc{titsias_2014,
-            title={Variational Inference for Gaussian and Determinantal Point Processes},
-            url={http://www2.aueb.gr/users/mtitsias/papers/titsiasNipsVar14.pdf},
-            publisher={Workshop on Advances in Variational Inference (NIPS 2014)},
-            author={Titsias, Michalis K.},
-            year={2014},
-            month={Dec}
-          }
+        The key reference is :cite:t:`titsias_2014`.
 
         The key quantity, the trace term, can be computed via
 
@@ -134,32 +123,24 @@ class SGPRBase_deprecated(GPModel, InternalDataTrainingLossMixin):
 
 class SGPR_deprecated(SGPRBase_deprecated):
     """
-    Sparse Variational GP regression. The key reference is
+    Sparse Variational GP regression.
 
-    ::
-
-        @inproceedings{titsias2009variational,
-            title={Variational learning of inducing variables in
-                sparse Gaussian processes},
-            author={Titsias, Michalis K},
-            booktitle={International Conference on
-                    Artificial Intelligence and Statistics},
-            pages={567--574},
-            year={2009}
-        }
+    The key reference is :cite:t:`titsias2009variational`.
     """
 
     CommonTensors = namedtuple("CommonTensors", ["A", "B", "LB", "AAT", "L"])
 
-    def maximum_log_likelihood_objective(self) -> tf.Tensor:
+    # type-ignore is because of changed method signature:
+    def maximum_log_likelihood_objective(self) -> tf.Tensor:  # type: ignore
         return self.elbo()
 
-    def _common_calculation(self):
+    def _common_calculation(self) -> "SGPR.CommonTensors":
         """
         Matrices used in log-det calculation
 
-        :return: A , B, LB, AAT with :math:`LLᵀ = Kᵤᵤ , A = L⁻¹K_{uf}/σ, AAT = AAᵀ, B = AAT+I, LBLBᵀ = B`
-        A is M x N, B is M x M, LB is M x M, AAT is M x M
+        :return: A , B, LB, AAT with :math:`LLᵀ = Kᵤᵤ , A = L⁻¹K_{uf}/σ, AAT = AAᵀ,
+            B = AAT+I, LBLBᵀ = B`
+            A is M x N, B is M x M, LB is M x M, AAT is M x M
         """
         x, _ = self.data
         iv = self.inducing_variable
@@ -178,14 +159,15 @@ class SGPR_deprecated(SGPRBase_deprecated):
 
         return self.CommonTensors(A, B, LB, AAT, L)
 
-    def logdet_term(self, common: NameError):
-        """
+    def logdet_term(self, common: "SGPR.CommonTensors") -> tf.Tensor:
+        r"""
         Bound from Jensen's Inequality:
+
         .. math::
-            log |K + σ²I| <= log |Q + σ²I| + N * log (1 + tr(K - Q)/(σ²N))
+            \log |K + σ²I| <= \log |Q + σ²I| + N * \log (1 + \textrm{tr}(K - Q)/(σ²N))
 
         :param common: A named tuple containing matrices that will be used
-        :return: log_det, lower bound on -.5 * output_dim * log |K + σ²I|
+        :return: log_det, lower bound on :math:`-.5 * \textrm{output_dim} * \log |K + σ²I|`
         """
         LB = common.LB
         AAT = common.AAT
@@ -212,7 +194,7 @@ class SGPR_deprecated(SGPRBase_deprecated):
         logdet_k = -outdim * (half_logdet_b + 0.5 * log_sigma_sq + 0.5 * trace)
         return logdet_k
 
-    def quad_term(self, common: NamedTuple) -> tf.Tensor:
+    def quad_term(self, common: "SGPR.CommonTensors") -> tf.Tensor:
         """
         :param common: A named tuple containing matrices that will be used
         :return: Lower bound on -.5 yᵀ(K + σ²I)⁻¹y
@@ -250,7 +232,9 @@ class SGPR_deprecated(SGPRBase_deprecated):
         quad = self.quad_term(common)
         return const + logdet + quad
 
-    def predict_f(self, Xnew: InputData, full_cov=False, full_output_cov=False) -> MeanAndVariance:
+    def predict_f(
+        self, Xnew: InputData, full_cov: bool = False, full_output_cov: bool = False
+    ) -> MeanAndVariance:
 
         # could copy into posterior into a fused version
         """
@@ -327,24 +311,16 @@ class SGPR_deprecated(SGPRBase_deprecated):
 class GPRFITC(SGPRBase_deprecated):
     """
     This implements GP regression with the FITC approximation.
-    The key reference is
 
-    ::
-
-      @inproceedings{Snelson06sparsegaussian,
-        author = {Edward Snelson and Zoubin Ghahramani},
-        title = {Sparse Gaussian Processes using Pseudo-inputs},
-        booktitle = {Advances In Neural Information Processing Systems},
-        year = {2006},
-        pages = {1257--1264},
-        publisher = {MIT press}
-      }
+    The key reference is :cite:t:`Snelson06sparsegaussian`.
 
     Implementation loosely based on code from GPML matlab library although
     obviously gradients are automatic in GPflow.
     """
 
-    def common_terms(self):
+    def common_terms(
+        self,
+    ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor, tf.Tensor, tf.Tensor, tf.Tensor, tf.Tensor]:
         X_data, Y_data = self.data
         num_inducing = self.inducing_variable.num_inducing
         err = Y_data - self.mean_function(X_data)  # size [N, R]
@@ -369,7 +345,8 @@ class GPRFITC(SGPRBase_deprecated):
 
         return err, nu, Luu, L, alpha, beta, gamma
 
-    def maximum_log_likelihood_objective(self) -> tf.Tensor:
+    # type-ignore is because of changed method signature:
+    def maximum_log_likelihood_objective(self) -> tf.Tensor:  # type: ignore
         return self.fitc_log_marginal_likelihood()
 
     def fitc_log_marginal_likelihood(self) -> tf.Tensor:
@@ -389,14 +366,18 @@ class GPRFITC(SGPRBase_deprecated):
 
         # We need to deal with the matrix inverse term.
         # K_fitc^{-1} = ( Qff + \diag( \nu ) )^{-1}
-        #            = ( V^T V + \diag( \nu ) )^{-1}
+        #             = ( V^T V + \diag( \nu ) )^{-1}
         # Applying the Woodbury identity we obtain
-        #            = \diag( \nu^{-1} ) - \diag( \nu^{-1} ) V^T ( I + V \diag( \nu^{-1} ) V^T )^{-1) V \diag(\nu^{-1} )
+        #             = \diag( \nu^{-1} )
+        #                 - \diag( \nu^{-1} ) V^T ( I + V \diag( \nu^{-1} ) V^T )^{-1}
+        #                     V \diag(\nu^{-1} )
         # Let \beta =  \diag( \nu^{-1} ) err
         # and let \alpha = V \beta
-        # then Mahalanobis term = -0.5* ( \beta^T err - \alpha^T Solve( I + V \diag( \nu^{-1} ) V^T, alpha ) )
+        # then Mahalanobis term = -0.5* (
+        #    \beta^T err - \alpha^T Solve( I + V \diag( \nu^{-1} ) V^T, alpha )
+        # )
 
-        err, nu, Luu, L, alpha, beta, gamma = self.common_terms()
+        err, nu, _Luu, L, _alpha, _beta, gamma = self.common_terms()
 
         mahalanobisTerm = -0.5 * tf.reduce_sum(
             tf.square(err) / tf.expand_dims(nu, 1)
@@ -406,10 +387,12 @@ class GPRFITC(SGPRBase_deprecated):
 
         # We need to deal with the log determinant term.
         # \log \det( K_fitc ) = \log \det( Qff + \diag( \nu ) )
-        #                    = \log \det( V^T V + \diag( \nu ) )
+        #                     = \log \det( V^T V + \diag( \nu ) )
         # Applying the determinant lemma we obtain
-        #                    = \log [ \det \diag( \nu ) \det( I + V \diag( \nu^{-1} ) V^T ) ]
-        #                    = \log [ \det \diag( \nu ) ] + \log [ \det( I + V \diag( \nu^{-1} ) V^T ) ]
+        #                     = \log [ \det \diag( \nu ) \det( I + V \diag( \nu^{-1} ) V^T ) ]
+        #                     = \log [
+        #                        \det \diag( \nu ) ] + \log [ \det( I + V \diag( \nu^{-1} ) V^T )
+        #                     ]
 
         constantTerm = -0.5 * self.num_data * tf.math.log(tf.constant(2.0 * np.pi, default_float()))
         logDeterminantTerm = -0.5 * tf.reduce_sum(tf.math.log(nu)) - tf.reduce_sum(
@@ -419,7 +402,9 @@ class GPRFITC(SGPRBase_deprecated):
 
         return mahalanobisTerm + logNormalizingTerm * self.num_latent_gps
 
-    def predict_f(self, Xnew: InputData, full_cov=False, full_output_cov=False) -> MeanAndVariance:
+    def predict_f(
+        self, Xnew: InputData, full_cov: bool = False, full_output_cov: bool = False
+    ) -> MeanAndVariance:
         """
         Compute the mean and variance of the latent function at some new points
         Xnew.
@@ -457,7 +442,10 @@ class SGPR_with_posterior(SGPR_deprecated):
     enables caching for faster subsequent predictions.
     """
 
-    def posterior(self, precompute_cache=posteriors.PrecomputeCacheType.TENSOR):
+    def posterior(
+        self,
+        precompute_cache: posteriors.PrecomputeCacheType = posteriors.PrecomputeCacheType.TENSOR,
+    ) -> posteriors.SGPRPosterior:
         """
         Create the Posterior object which contains precomputed matrices for
         faster prediction.
@@ -487,7 +475,9 @@ class SGPR_with_posterior(SGPR_deprecated):
             precompute_cache=precompute_cache,
         )
 
-    def predict_f(self, Xnew: InputData, full_cov=False, full_output_cov=False) -> MeanAndVariance:
+    def predict_f(
+        self, Xnew: InputData, full_cov: bool = False, full_output_cov: bool = False
+    ) -> MeanAndVariance:
         """
         For backwards compatibility, GPR's predict_f uses the fused (no-cache)
         computation, which is more efficient during training.
