@@ -12,47 +12,45 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Optional
+
 import numpy as np
 import tensorflow as tf
 
 from .. import kullback_leiblers, posteriors
-from ..base import InputData, MeanAndVariance, Parameter, RegressionData
+from ..base import AnyNDArray, InputData, MeanAndVariance, Parameter, RegressionData
 from ..conditionals import conditional
 from ..config import default_float
+from ..inducing_variables import InducingVariables
+from ..kernels import Kernel
+from ..likelihoods import Likelihood
+from ..mean_functions import MeanFunction
 from ..utilities import positive, triangular
 from .model import GPModel
 from .training_mixins import ExternalDataTrainingLossMixin
-from .util import inducingpoint_wrapper
+from .util import InducingVariablesLike, inducingpoint_wrapper
 
 
 class SVGP_deprecated(GPModel, ExternalDataTrainingLossMixin):
     """
-    This is the Sparse Variational GP (SVGP). The key reference is
-
-    ::
-
-      @inproceedings{hensman2014scalable,
-        title={Scalable Variational Gaussian Process Classification},
-        author={Hensman, James and Matthews, Alexander G. de G. and Ghahramani, Zoubin},
-        booktitle={Proceedings of AISTATS},
-        year={2015}
-      }
+    This is the Sparse Variational GP (SVGP).
 
+    The key reference is :cite:t:`hensman2014scalable`.
     """
 
     def __init__(
         self,
-        kernel,
-        likelihood,
-        inducing_variable,
+        kernel: Kernel,
+        likelihood: Likelihood,
+        inducing_variable: InducingVariablesLike,
         *,
-        mean_function=None,
+        mean_function: Optional[MeanFunction] = None,
         num_latent_gps: int = 1,
         q_diag: bool = False,
-        q_mu=None,
-        q_sqrt=None,
+        q_mu: Optional[tf.Tensor] = None,
+        q_sqrt: Optional[tf.Tensor] = None,
         whiten: bool = True,
-        num_data=None,
+        num_data: Optional[tf.Tensor] = None,
     ):
         """
         - kernel, likelihood, inducing_variables, mean_function are appropriate
@@ -68,37 +66,42 @@ class SVGP_deprecated(GPModel, ExternalDataTrainingLossMixin):
         # init the super class, accept args
         super().__init__(kernel, likelihood, mean_function, num_latent_gps)
         self.num_data = num_data
-        self.q_diag = q_diag
         self.whiten = whiten
-        self.inducing_variable = inducingpoint_wrapper(inducing_variable)
+        self.inducing_variable: InducingVariables = inducingpoint_wrapper(inducing_variable)
 
         # init variational parameters
         num_inducing = self.inducing_variable.num_inducing
         self._init_variational_parameters(num_inducing, q_mu, q_sqrt, q_diag)
 
-    def _init_variational_parameters(self, num_inducing, q_mu, q_sqrt, q_diag):
+    def _init_variational_parameters(
+        self,
+        num_inducing: int,
+        q_mu: Optional[AnyNDArray],
+        q_sqrt: Optional[AnyNDArray],
+        q_diag: bool,
+    ) -> None:
         """
         Constructs the mean and cholesky of the covariance of the variational Gaussian posterior.
         If a user passes values for `q_mu` and `q_sqrt` the routine checks if they have consistent
-        and correct shapes. If a user does not specify any values for `q_mu` and `q_sqrt`, the routine
-        initializes them, their shape depends on `num_inducing` and `q_diag`.
+        and correct shapes. If a user does not specify any values for `q_mu` and `q_sqrt`, the
+        routine initializes them, their shape depends on `num_inducing` and `q_diag`.
 
-        Note: most often the comments refer to the number of observations (=output dimensions) with P,
-        number of latent GPs with L, and number of inducing points M. Typically P equals L,
+        Note: most often the comments refer to the number of observations (=output dimensions) with
+        P, number of latent GPs with L, and number of inducing points M. Typically P equals L,
         but when certain multioutput kernels are used, this can change.
 
         Parameters
         ----------
-        :param num_inducing: int
+        :param num_inducing:
             Number of inducing variables, typically refered to as M.
-        :param q_mu: np.array or None
+        :param q_mu:
             Mean of the variational Gaussian posterior. If None the function will initialise
             the mean with zeros. If not None, the shape of `q_mu` is checked.
-        :param q_sqrt: np.array or None
+        :param q_sqrt:
             Cholesky of the covariance of the variational Gaussian posterior.
             If None the function will initialise `q_sqrt` with identity matrix.
             If not None, the shape of `q_sqrt` is checked, depending on `q_diag`.
-        :param q_diag: bool
+        :param q_diag:
             Used to check if `q_mu` and `q_sqrt` have the correct shape or to
             construct them with the correct shape. If `q_diag` is true,
             `q_sqrt` is two dimensional and only holds the square root of the
@@ -108,15 +111,19 @@ class SVGP_deprecated(GPModel, ExternalDataTrainingLossMixin):
         self.q_mu = Parameter(q_mu, dtype=default_float())  # [M, P]
 
         if q_sqrt is None:
-            if self.q_diag:
-                ones = np.ones((num_inducing, self.num_latent_gps), dtype=default_float())
+            if q_diag:
+                ones: AnyNDArray = np.ones(
+                    (num_inducing, self.num_latent_gps), dtype=default_float()
+                )
                 self.q_sqrt = Parameter(ones, transform=positive())  # [M, P]
             else:
-                q_sqrt = [
-                    np.eye(num_inducing, dtype=default_float()) for _ in range(self.num_latent_gps)
-                ]
-                q_sqrt = np.array(q_sqrt)
-                self.q_sqrt = Parameter(q_sqrt, transform=triangular())  # [P, M, M]
+                np_q_sqrt: AnyNDArray = np.array(
+                    [
+                        np.eye(num_inducing, dtype=default_float())
+                        for _ in range(self.num_latent_gps)
+                    ]
+                )
+                self.q_sqrt = Parameter(np_q_sqrt, transform=triangular())  # [P, M, M]
         else:
             if q_diag:
                 assert q_sqrt.ndim == 2
@@ -133,7 +140,8 @@ class SVGP_deprecated(GPModel, ExternalDataTrainingLossMixin):
             self.inducing_variable, self.kernel, self.q_mu, self.q_sqrt, whiten=self.whiten
         )
 
-    def maximum_log_likelihood_objective(self, data: RegressionData) -> tf.Tensor:
+    # type-ignore is because of changed method signature:
+    def maximum_log_likelihood_objective(self, data: RegressionData) -> tf.Tensor:  # type: ignore
         return self.elbo(data)
 
     def elbo(self, data: RegressionData) -> tf.Tensor:
@@ -153,7 +161,9 @@ class SVGP_deprecated(GPModel, ExternalDataTrainingLossMixin):
             scale = tf.cast(1.0, kl.dtype)
         return tf.reduce_sum(var_exp) * scale - kl
 
-    def predict_f(self, Xnew: InputData, full_cov=False, full_output_cov=False) -> MeanAndVariance:
+    def predict_f(
+        self, Xnew: InputData, full_cov: bool = False, full_output_cov: bool = False
+    ) -> MeanAndVariance:
         mu, var = conditional(
             Xnew,
             self.inducing_variable,
@@ -170,21 +180,17 @@ class SVGP_deprecated(GPModel, ExternalDataTrainingLossMixin):
 
 class SVGP_with_posterior(SVGP_deprecated):
     """
-    This is the Sparse Variational GP (SVGP). The key reference is
+    This is the Sparse Variational GP (SVGP).
 
-    ::
-
-      @inproceedings{hensman2014scalable,
-        title={Scalable Variational Gaussian Process Classification},
-        author={Hensman, James and Matthews, Alexander G. de G. and Ghahramani, Zoubin},
-        booktitle={Proceedings of AISTATS},
-        year={2015}
-      }
+    The key reference is :cite:t:`hensman2014scalable`.
 
     This class provides a posterior() method that enables caching for faster subsequent predictions.
     """
 
-    def posterior(self, precompute_cache=posteriors.PrecomputeCacheType.TENSOR):
+    def posterior(
+        self,
+        precompute_cache: posteriors.PrecomputeCacheType = posteriors.PrecomputeCacheType.TENSOR,
+    ) -> posteriors.BasePosterior:
         """
         Create the Posterior object which contains precomputed matrices for
         faster prediction.
@@ -213,7 +219,9 @@ class SVGP_with_posterior(SVGP_deprecated):
             precompute_cache=precompute_cache,
         )
 
-    def predict_f(self, Xnew: InputData, full_cov=False, full_output_cov=False) -> MeanAndVariance:
+    def predict_f(
+        self, Xnew: InputData, full_cov: bool = False, full_output_cov: bool = False
+    ) -> MeanAndVariance:
         """
         For backwards compatibility, SVGP's predict_f uses the fused (no-cache)
         computation, which is more efficient during training.
