@@ -15,38 +15,40 @@
 import copy
 import re
 from functools import lru_cache
-from typing import Any, Callable, Dict, Mapping, Optional, Tuple, TypeVar, Union
+from typing import Any, Callable, Dict, Mapping, Optional, Pattern, Tuple, Type, TypeVar, Union
 
-import numpy as np
 import tensorflow as tf
 import tensorflow_probability as tfp
 from packaging.version import Version
 from tabulate import tabulate
+from tensorflow.python.util.object_identity import Reference
 
-from ..base import Parameter
+from ..base import AnyNDArray, Parameter
 from ..config import default_summary_fmt
 
 __all__ = [
-    "multiple_assign",
-    "print_summary",
-    "tabulate_module_summary",
     "deepcopy",
     "freeze",
     "leaf_components",
+    "multiple_assign",
     "parameter_dict",
+    "print_summary",
     "read_values",
     "reset_cache_bijectors",
     "select_dict_parameters_with_prior",
+    "tabulate_module_summary",
 ]
-
+LeafComponent = Union[tf.Variable, tf.Tensor, Parameter]
+LeafVariable = Union[tf.Variable, Parameter]
+HashableTensor = Union[Reference, Parameter]
 TraverseInput = TypeVar("TraverseInput", tf.Variable, tf.Module, Parameter)
-State = Any
+State = TypeVar("State")
 Path = str
 Accumulator = Tuple[Path, State]
 TraverseUpdateCallable = Callable[[TraverseInput, Path, State], State]
 
 
-def multiple_assign(module: tf.Module, parameters: Mapping[str, tf.Tensor]):
+def multiple_assign(module: tf.Module, parameters: Mapping[Path, tf.Tensor]) -> None:
     """
     Multiple assign takes a dictionary with new values. Dictionary keys are paths to the
     `tf.Variable`s or `gpflow.Parameter` of the input module.
@@ -59,12 +61,12 @@ def multiple_assign(module: tf.Module, parameters: Mapping[str, tf.Tensor]):
         reference_var_dict[path].assign(value)
 
 
-def read_values(module: tf.Module) -> Dict[str, np.ndarray]:
+def read_values(module: tf.Module) -> Dict[Path, AnyNDArray]:
     """Returns a dictionary of numpy values of the module parameters (variables)."""
     return {k: v.numpy() for k, v in parameter_dict(module).items()}
 
 
-def parameter_dict(module: tf.Module) -> Dict[str, Union[Parameter, tf.Variable]]:
+def parameter_dict(module: tf.Module) -> Dict[Path, LeafVariable]:
     """
     Returns a dictionary of parameters (variables) for the `tf.Module` component.
     Dictionary keys are relative paths to the attributes to which parameters (variables) assigned to.
@@ -89,7 +91,7 @@ def parameter_dict(module: tf.Module) -> Dict[str, Union[Parameter, tf.Variable]
     return {f".{key.split('.', 1)[-1]}": value for key, value in param_dict.items()}
 
 
-def print_summary(module: tf.Module, fmt: str = None):
+def print_summary(module: tf.Module, fmt: Optional[str] = None) -> None:
     """
     Prints a summary of the parameters and variables contained in a tf.Module.
     """
@@ -104,16 +106,16 @@ def print_summary(module: tf.Module, fmt: str = None):
 
 
 def tabulate_module_summary(module: tf.Module, tablefmt: Optional[str] = None) -> str:
-    def get_transform(path, var):
+    def get_transform(path: Path, var: LeafComponent) -> Optional[str]:
         if hasattr(var, "transform") and var.transform is not None:
             if isinstance(var.transform, tfp.bijectors.Chain):
                 return " + ".join(b.__class__.__name__ for b in var.transform.bijectors[::-1])
-            return var.transform.__class__.__name__
+            return var.transform.__class__.__name__  # type: ignore
         return None
 
-    def get_prior(path, var):
+    def get_prior(path: Path, var: LeafComponent) -> Optional[str]:
         if hasattr(var, "prior") and var.prior is not None:
-            return var.prior.name
+            return var.prior.name  # type: ignore
         return None
 
     # list of (column_name: str, column_getter: Callable[[tf.Variable], str]) tuples:
@@ -135,25 +137,28 @@ def tabulate_module_summary(module: tf.Module, tablefmt: Optional[str] = None) -
         [getter(path, variable) for getter in column_getters]
         for path, variable in merged_leaf_components.items()
     ]
-    return tabulate(column_values, headers=column_names, tablefmt=tablefmt)
+    # mypy claims it's wrong to pass a `None` tablefmt below. I think `tabulate` has bad type hints.
+    return tabulate(column_values, headers=column_names, tablefmt=tablefmt)  # type: ignore
 
 
-def leaf_components(input: tf.Module):
+def leaf_components(input: tf.Module) -> Mapping[Path, LeafVariable]:
     return _get_leaf_components(input)
 
 
-def _merge_leaf_components(
-    input: Dict[str, Union[tf.Variable, tf.Tensor, Parameter]]
-) -> Dict[str, Union[tf.Variable, tf.Tensor, Parameter]]:
+def _merge_leaf_components(input: Mapping[Path, LeafComponent]) -> Mapping[Path, LeafComponent]:
 
-    ref_fn = lambda x: (x if isinstance(x, Parameter) else x.ref())
-    deref_fn = lambda x: (x if isinstance(x, Parameter) else x.deref())
+    ref_fn: Callable[[LeafComponent], HashableTensor] = lambda x: (
+        x if isinstance(x, Parameter) else x.ref()
+    )
+    deref_fn: Callable[[HashableTensor], LeafComponent] = lambda x: (
+        x if isinstance(x, Parameter) else x.deref()
+    )
 
-    input_values = set([ref_fn(value) for value in input.values()])
+    input_values = {ref_fn(value) for value in input.values()}
     if len(input_values) == len(input):
         return input
 
-    tmp_dict = dict()  # Type: Dict[ref, str]
+    tmp_dict: Dict[HashableTensor, Path] = {}
     for key, value in input.items():
         ref = ref_fn(value)
         if ref in tmp_dict:
@@ -163,7 +168,7 @@ def _merge_leaf_components(
     return {key: deref_fn(ref) for ref, key in tmp_dict.items()}
 
 
-def _get_leaf_components(input_module: tf.Module):
+def _get_leaf_components(input_module: tf.Module) -> Mapping[Path, LeafVariable]:
     """
     Returns a list of tuples each corresponding to a gpflow.Parameter or tf.Variable in the each
     submodules of a given tf.Module. Each tuple consists of an specific Parameter (or Variable) and
@@ -174,10 +179,13 @@ def _get_leaf_components(input_module: tf.Module):
     :return:
     """
     target_types = (Parameter, tf.Variable)
-    input_name, state = input_module.__class__.__name__, dict()
+    input_name = input_module.__class__.__name__
+    state: Dict[Path, LeafVariable] = {}
     accumulator = (input_name, state)
 
-    def update_state(parameter_or_variable, path, state):
+    def update_state(
+        parameter_or_variable: LeafVariable, path: Path, state: Dict[Path, LeafVariable]
+    ) -> Dict[Path, LeafVariable]:
         state[path] = parameter_or_variable
         return state
 
@@ -197,13 +205,13 @@ def reset_cache_bijectors(input_module: tf.Module) -> tf.Module:
         if hasattr(tfp.bijectors.Identity()._cache, "clear"):
             # implementation in `master` branch (checked 29 Sep 2020) provides clear():
 
-            def _clear_bijector_cache(bijector: tfp.bijectors.Bijector):
+            def _clear_bijector_cache(bijector: tfp.bijectors.Bijector) -> None:
                 bijector._cache.clear()
 
         else:  # pragma: no cover
             # previous versions (including the versions 0.11.0 and 0.11.1 released as of 29 Sep 2020) provide reset(), but its implementation is broken
 
-            def _clear_bijector_cache(bijector: tfp.bijectors.Bijector):
+            def _clear_bijector_cache(bijector: tfp.bijectors.Bijector) -> None:
                 # workaround for broken implementation of bijector._cache.reset():
                 cache = bijector._cache
                 cache_type = type(cache.forward)
@@ -213,7 +221,7 @@ def reset_cache_bijectors(input_module: tf.Module) -> tf.Module:
     else:  # pragma: no cover
         # fallback for backwards-compatibility with tensorflow_probability < 0.11.0
 
-        def _clear_bijector_cache(bijector: tfp.bijectors.Bijector):
+        def _clear_bijector_cache(bijector: tfp.bijectors.Bijector) -> None:
             # `_from_x` and `_from_y` are cache dictionaries for forward and inverse transformations
             bijector._from_x.clear()
             bijector._from_y.clear()
@@ -221,7 +229,7 @@ def reset_cache_bijectors(input_module: tf.Module) -> tf.Module:
     target_types = (tfp.bijectors.Bijector,)
     accumulator = ("", None)
 
-    def clear_bijector(bijector, _, state):
+    def clear_bijector(bijector: tfp.bijectors.Bijector, _: Path, state: None) -> None:
         if not isinstance(bijector, tfp.bijectors.Bijector):
             return  # skip submodules that are not bijectors
 
@@ -235,7 +243,7 @@ def reset_cache_bijectors(input_module: tf.Module) -> tf.Module:
 
         return state
 
-    _ = traverse_module(input_module, accumulator, clear_bijector, target_types)
+    traverse_module(input_module, accumulator, clear_bijector, target_types)
     return input_module
 
 
@@ -248,10 +256,11 @@ def deepcopy(input_module: M, memo: Optional[Dict[int, Any]] = None) -> M:
     tfp.bijectors.Bijector to allow the deepcopy of the tf.Module.
 
     :param input_module: tf.Module including keras.Model, keras.layers.Layer and gpflow.Module.
-    :param memo: passed through to func:`copy.deepcopy` (see https://docs.python.org/3/library/copy.html).
+    :param memo: passed through to func:`copy.deepcopy`
+        (see https://docs.python.org/3/library/copy.html).
     :return: Returns a deepcopy of an input object.
     """
-    return copy.deepcopy(reset_cache_bijectors(input_module), memo)
+    return copy.deepcopy(reset_cache_bijectors(input_module), memo)  # type: ignore
 
 
 def freeze(input_module: M) -> M:
@@ -268,11 +277,14 @@ def freeze(input_module: M) -> M:
 
 
 def traverse_module(
-    m: TraverseInput, acc: Accumulator, update_cb: TraverseUpdateCallable, target_types: tuple
-) -> Accumulator:
+    m: TraverseInput,
+    acc: Accumulator[State],
+    update_cb: TraverseUpdateCallable[TraverseInput, State],
+    target_types: Tuple[Type[Any], ...],
+) -> State:
     """
-    Recursively traverses `m`, accumulating in `acc` a path and a state until it finds an object of type
-    in `target_types` to apply `update_cb` to update the accumulator `acc` and/or the object.
+    Recursively traverses `m`, accumulating in `acc` a path and a state until it finds an object of
+    type in `target_types` to apply `update_cb` to update the accumulator `acc` and/or the object.
 
     :param m: tf.Module, tf.Variable or gpflow.Parameter
     :param acc: Tuple of path and state
@@ -311,13 +323,13 @@ def traverse_module(
 
 
 @lru_cache()
-def _first_three_elements_regexp():
+def _first_three_elements_regexp() -> Pattern[str]:
     num_re = r"[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?"
     pat_re = rf"^(?:(\[+)\s*)?({num_re})(?:\s+({num_re})(?:\s+({num_re}))?)?.*?"
     return re.compile(pat_re)
 
 
-def _str_tensor_value(value: np.ndarray):
+def _str_tensor_value(value: AnyNDArray) -> str:
     value_str = str(value)
     if value.size <= 3:
         return value_str
@@ -340,7 +352,7 @@ def _str_tensor_value(value: np.ndarray):
     return out
 
 
-def select_dict_parameters_with_prior(model: tf.Module) -> Dict[str, Parameter]:
+def select_dict_parameters_with_prior(model: tf.Module) -> Dict[Path, Parameter]:
     """Collects parameters with prior into a dictionary."""
     return {
         k: p
