@@ -1,9 +1,11 @@
 import numpy as np
 
+from gpflow.base import AnyNDArray
+
 
 def ref_rbf_kernel(
-    X: np.ndarray, lengthscales: np.ndarray, signal_variance: np.ndarray
-) -> np.ndarray:
+    X: AnyNDArray, lengthscales: AnyNDArray, signal_variance: AnyNDArray
+) -> AnyNDArray:
     N, _ = X.shape
     kernel = np.zeros((N, N))
     for row_index in range(N):
@@ -19,12 +21,12 @@ def ref_rbf_kernel(
 
 
 def ref_arccosine_kernel(
-    X: np.ndarray,
-    order: np.ndarray,
-    weight_variances: np.ndarray,
-    bias_variance: np.ndarray,
-    signal_variance: np.ndarray,
-) -> np.ndarray:
+    X: AnyNDArray,
+    order: int,
+    weight_variances: AnyNDArray,
+    bias_variance: AnyNDArray,
+    signal_variance: AnyNDArray,
+) -> AnyNDArray:
     num_points = X.shape[0]
     kernel = np.empty((num_points, num_points))
     for row in range(num_points):
@@ -58,17 +60,18 @@ def ref_arccosine_kernel(
 
 
 def ref_periodic_kernel(
-    X: np.ndarray,
-    base_name: np.ndarray,
-    lengthscales: np.ndarray,
-    signal_variance: np.ndarray,
-    period: np.ndarray,
-) -> np.ndarray:
+    X: AnyNDArray,
+    base_name: str,
+    lengthscales: AnyNDArray,
+    signal_variance: AnyNDArray,
+    period: AnyNDArray,
+) -> AnyNDArray:
     """
     Calculates K(X) for the periodic kernel based on various base kernels.
     """
     sine_arg = np.pi * (X[:, None, :] - X[None, :, :]) / period
     sine_base = np.sin(sine_arg) / lengthscales
+    exp_dist: AnyNDArray
     if base_name in {"RBF", "SquaredExponential"}:
         dist = 0.5 * np.sum(np.square(sine_base), axis=-1)
         exp_dist = np.exp(-dist)
@@ -81,4 +84,4 @@ def ref_periodic_kernel(
     elif base_name == "Matern52":
         dist = np.sqrt(5) * np.sum(np.abs(sine_base), axis=-1)
         exp_dist = (1 + dist + dist ** 2 / 3) * np.exp(-dist)
-    return signal_variance * exp_dist
+    return signal_variance * exp_dist  # type: ignore
