@@ -11,13 +11,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Tuple
+from typing import Sequence, Tuple
 
 import numpy as np
 from numpy.testing import assert_allclose
 
 import gpflow
 from gpflow import set_trainable
+from gpflow.base import AnyNDArray
 from gpflow.mean_functions import Constant
 from gpflow.models import VGP
 
@@ -26,27 +27,27 @@ rng = np.random.RandomState(0)
 
 class Datum:
     N1, N2 = 6, 16
-    X = [rng.rand(N1, 2) * 1, rng.rand(N2, 2) * 1]
+    X: Sequence[AnyNDArray] = [rng.rand(N1, 2) * 1, rng.rand(N2, 2) * 1]
     Y = [
         np.sin(x[:, :1]) + 0.9 * np.cos(x[:, 1:2] * 1.6) + rng.randn(x.shape[0], 1) * 0.8 for x in X
     ]
-    label = [np.zeros((N1, 1)), np.ones((N2, 1))]
-    X_augmented0 = np.hstack([X[0], label[0]])
-    X_augmented1 = np.hstack([X[1], label[1]])
-    X_augmented = np.vstack([X_augmented0, X_augmented1])
+    label: Sequence[AnyNDArray] = [np.zeros((N1, 1)), np.ones((N2, 1))]
+    X_augmented0: AnyNDArray = np.hstack([X[0], label[0]])
+    X_augmented1: AnyNDArray = np.hstack([X[1], label[1]])
+    X_augmented: AnyNDArray = np.vstack([X_augmented0, X_augmented1])
 
-    Y_augmented0 = np.hstack([Y[0], label[0]])
-    Y_augmented1 = np.hstack([Y[1], label[1]])
-    Y_augmented = np.vstack([Y_augmented0, Y_augmented1])
+    Y_augmented0: AnyNDArray = np.hstack([Y[0], label[0]])
+    Y_augmented1: AnyNDArray = np.hstack([Y[1], label[1]])
+    Y_augmented: AnyNDArray = np.vstack([Y_augmented0, Y_augmented1])
 
     # For predict tests
     N = 10
-    Xtest = rng.rand(N, 2) * N
-    Xtest_augmented0 = np.hstack([Xtest, np.zeros((N, 1))])
-    Xtest_augmented1 = np.hstack([Xtest, np.ones((N, 1))])
+    Xtest: AnyNDArray = rng.rand(N, 2) * N
+    Xtest_augmented0: AnyNDArray = np.hstack([Xtest, np.zeros((N, 1))])
+    Xtest_augmented1: AnyNDArray = np.hstack([Xtest, np.ones((N, 1))])
     Ytest = np.sin(Xtest[:, :1]) + 0.9 * np.cos(Xtest[:, 1:2] * 1.6)
-    Ytest_augmented0 = np.hstack([Ytest, np.zeros((N, 1))])
-    Ytest_augmented1 = np.hstack([Ytest, np.ones((N, 1))])
+    Ytest_augmented0: AnyNDArray = np.hstack([Ytest, np.zeros((N, 1))])
+    Ytest_augmented1: AnyNDArray = np.hstack([Ytest, np.ones((N, 1))])
 
 
 def _prepare_models() -> Tuple[VGP, VGP, VGP]:
