@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Any, Optional, Tuple
 
 import numpy as np
 import pytest
@@ -7,6 +7,9 @@ import tensorflow as tf
 import gpflow
 from gpflow import set_trainable
 from gpflow.config import default_float
+from gpflow.kernels import Kernel, SquaredExponential
+from gpflow.likelihoods import Gaussian, Likelihood
+from gpflow.models import GPR, SGPR, SVGP, VGP, BayesianModel
 from gpflow.optimizers import NaturalGradient
 
 
@@ -20,32 +23,34 @@ class Setup:
 
 
 @pytest.fixture
-def data():
+def data() -> Tuple[tf.Tensor, tf.Tensor]:
     X = tf.convert_to_tensor(Setup.X, dtype=default_float())
     Y = tf.convert_to_tensor(Setup.Y, dtype=default_float())
     return (X, Y)
 
 
 @pytest.fixture
-def inducing_variable():
+def inducing_variable() -> tf.Tensor:
     Z = tf.convert_to_tensor(Setup.Z, dtype=default_float())
     return Z
 
 
 @pytest.fixture
-def kernel():
-    return gpflow.kernels.SquaredExponential()
+def kernel() -> Kernel:
+    return SquaredExponential()
 
 
 @pytest.fixture
-def likelihood():
-    return gpflow.likelihoods.Gaussian(variance=Setup.likelihood_variance)
+def likelihood() -> Likelihood:
+    return Gaussian(variance=Setup.likelihood_variance)
 
 
 @pytest.fixture
-def gpr_and_vgp(data, kernel, likelihood):
-    vgp = gpflow.models.VGP(data, kernel, likelihood)
-    gpr = gpflow.models.GPR(data, kernel)
+def gpr_and_vgp(
+    data: Tuple[tf.Tensor, tf.Tensor], kernel: Kernel, likelihood: Likelihood
+) -> Tuple[GPR, VGP]:
+    vgp = VGP(data, kernel, likelihood)
+    gpr = GPR(data, kernel)
     gpr.likelihood.variance.assign(likelihood.variance)
     set_trainable(vgp, False)
     set_trainable(vgp.q_mu, True)
@@ -54,9 +59,14 @@ def gpr_and_vgp(data, kernel, likelihood):
 
 
 @pytest.fixture
-def sgpr_and_svgp(data, inducing_variable, kernel, likelihood):
-    svgp = gpflow.models.SVGP(kernel, likelihood, inducing_variable)
-    sgpr = gpflow.models.SGPR(data, kernel, inducing_variable=inducing_variable)
+def sgpr_and_svgp(
+    data: Tuple[tf.Tensor, tf.Tensor],
+    inducing_variable: tf.Tensor,
+    kernel: Kernel,
+    likelihood: Likelihood,
+) -> Tuple[SGPR, SVGP]:
+    svgp = SVGP(kernel, likelihood, inducing_variable)
+    sgpr = SGPR(data, kernel, inducing_variable=inducing_variable)
     sgpr.likelihood.variance.assign(Setup.likelihood_variance)
     set_trainable(svgp, False)
     set_trainable(svgp.q_mu, True)
@@ -64,19 +74,19 @@ def sgpr_and_svgp(data, inducing_variable, kernel, likelihood):
     return sgpr, svgp
 
 
-def assert_different(value1, value2, rtol=0.07):
+def assert_different(value1: tf.Tensor, value2: tf.Tensor, rtol: float = 0.07) -> None:
     """ assert relative difference > rtol """
     relative_difference = (value1 - value2) / (value1 + value2)
     assert np.abs(relative_difference) > rtol
 
 
 def assert_gpr_vs_vgp(
-    m1: gpflow.models.BayesianModel,
-    m2: gpflow.models.BayesianModel,
+    m1: BayesianModel,
+    m2: BayesianModel,
     gamma: float = 1.0,
     maxiter: int = 1,
     xi_transform: Optional[gpflow.optimizers.natgrad.XiTransform] = None,
-):
+) -> None:
     assert maxiter >= 1
 
     m1_ll_before = m1.training_loss()
@@ -84,15 +94,15 @@ def assert_gpr_vs_vgp(
 
     assert_different(m2_ll_before, m1_ll_before)
 
-    params = (m2.q_mu, m2.q_sqrt)
+    params: Tuple[Any, ...] = (m2.q_mu, m2.q_sqrt)
     if xi_transform is not None:
         params += (xi_transform,)
 
     opt = NaturalGradient(gamma)
 
     @tf.function
-    def minimize_step():
-        opt.minimize(m2.training_loss, var_list=[params])
+    def minimize_step() -> None:
+        opt.minimize(m2.training_loss, var_list=[params])  # type: ignore
 
     for _ in range(maxiter):
         minimize_step()
@@ -104,9 +114,9 @@ def assert_gpr_vs_vgp(
 
 
 def assert_sgpr_vs_svgp(
-    m1: gpflow.models.BayesianModel,
-    m2: gpflow.models.BayesianModel,
-):
+    m1: BayesianModel,
+    m2: BayesianModel,
+) -> None:
     data = m1.data
 
     m1_ll_before = m1.training_loss()
@@ -124,18 +134,21 @@ def assert_sgpr_vs_svgp(
     np.testing.assert_allclose(m1_ll_after, m2_ll_after, atol=1e-4)
 
 
-def test_vgp_vs_gpr(gpr_and_vgp):
+def test_vgp_vs_gpr(gpr_and_vgp: Tuple[GPR, VGP]) -> None:
     """
-    With a Gaussian likelihood the Gaussian variational (VGP) model should be equivalent to the exact
-    regression model (GPR) after a single nat grad step of size 1
+    With a Gaussian likelihood the Gaussian variational (VGP) model should be equivalent to the
+    exact regression model (GPR) after a single nat grad step of size 1
     """
     gpr, vgp = gpr_and_vgp
     assert_gpr_vs_vgp(gpr, vgp)
 
 
-def test_small_q_sqrt_handeled_correctly(gpr_and_vgp, data):
+def test_small_q_sqrt_handeled_correctly(
+    gpr_and_vgp: Tuple[GPR, VGP], data: Tuple[tf.Tensor, tf.Tensor]
+) -> None:
     """
-    This is an extra test to make sure things still work when q_sqrt is small. This was breaking (#767)
+    This is an extra test to make sure things still work when q_sqrt is small.
+    This was breaking (#767)
     """
     gpr, vgp = gpr_and_vgp
     vgp.q_mu.assign(np.random.randn(data[0].shape[0], 1))
@@ -143,7 +156,7 @@ def test_small_q_sqrt_handeled_correctly(gpr_and_vgp, data):
     assert_gpr_vs_vgp(gpr, vgp)
 
 
-def test_svgp_vs_sgpr(sgpr_and_svgp):
+def test_svgp_vs_sgpr(sgpr_and_svgp: Tuple[SGPR, SVGP]) -> None:
     """
     With a Gaussian likelihood the sparse Gaussian variational (SVGP) model
     should be equivalent to the analytically optimial sparse regression model (SGPR)
@@ -168,7 +181,9 @@ class XiEta(gpflow.optimizers.XiTransform):
 
 
 @pytest.mark.parametrize("xi_transform", [gpflow.optimizers.XiSqrtMeanVar(), XiEta()])
-def test_xi_transform_vgp_vs_gpr(gpr_and_vgp, xi_transform):
+def test_xi_transform_vgp_vs_gpr(
+    gpr_and_vgp: Tuple[GPR, VGP], xi_transform: gpflow.optimizers.XiTransform
+) -> None:
     """
     With other transforms the solution is not given in a single step, but it should still give the same answer
     after a number of smaller steps.
